@@ -7,17 +7,19 @@ from typing import Tuple, Optional
 
 class StationATechnogenetics(StationAP1000):
     def __init__(self,
-        beads_mix_repeats: int = 2,
+        beads_mix_repeats: int = 0,
         beads_mix_volume: float = 20,
         beads_vol: float = 10,
-        drop_threshold: int = 95,
+        drop_threshold: int = 5000,
         ic_headroom_bottom = 1,
         lysis_first: bool = False,
         lys_mix_repeats: int = 2,
         lys_mix_volume: float = 100,
         lysis_volume: float = 400,
+        lysis_in_controls: bool = True,
         mix_repeats: int = 1,
-        positive_control_well = None,
+        negative_control_well='A1',
+        positive_control_well=None,
         prot_k_capacity: float = 180,
         prot_k_headroom: float = 1.1,
         prot_k_vol: float = 30,
@@ -51,7 +53,9 @@ class StationATechnogenetics(StationAP1000):
             lys_mix_repeats=lys_mix_repeats,
             lys_mix_volume=lys_mix_volume,
             lysis_volume=lysis_volume,
+            lysis_in_controls=lysis_in_controls,
             mix_repeats=mix_repeats,
+            negative_control_well=negative_control_well,
             positive_control_well=positive_control_well,
             sample_aspirate=sample_aspirate,
             sample_dispense=sample_dispense,
@@ -118,7 +122,8 @@ class StationATechnogenetics(StationAP1000):
             if self.run_stage("transfer beads {}/{}".format(i + 1, len(self._dests_multi))):
                 self.pick_up(self._m20)
                 self._m20.transfer(self._beads_vol, self._beads, d.bottom(self._dest_multi_headroom_height), air_gap=self._air_gap_dest_multi, new_tip='never')
-                self._m20.mix(self._beads_mix_repeats, self._beads_mix_volume, d.bottom(self._dest_multi_headroom_height))
+                if self._beads_mix_repeats:
+                    self._m20.mix(self._beads_mix_repeats, self._beads_mix_volume, d.bottom(self._dest_multi_headroom_height))
                 self._m20.air_gap(self._air_gap_dest_multi)
                 self._m20.drop_tip()
     
@@ -182,9 +187,8 @@ class StationATechnogenetics48(StationATechnogeneticsReload):
             ) for i, slot in enumerate(self._source_racks_slots)
         ]
 
-
 if __name__ == "__main__":
-    StationATechnogenetics24(num_samples=96, metadata={'apiLevel': '2.7'}).simulate()
+    StationATechnogenetics48(num_samples=96, metadata={'apiLevel': '2.7'}).simulate()
 
 
 # Copyright (c) 2020 Covmatic.
