@@ -16,7 +16,7 @@ class BioerProtocol(Station):
             mix_bottom_height = 0.5,
             mix_bottom_height_dw = -1.8,
             mm_plate_bottom_height = 1.2,
-            dw_elutes_bottom_height = -2,
+            dw_elutes_bottom_height = -3,
             pk_volume_tube = 320,
             vol_pk_offset = 5,
             vol_mm_offset = 10,
@@ -24,6 +24,7 @@ class BioerProtocol(Station):
             headroom_vol_from_tubes_to_pcr = 60,
             headroom_vol_from_tubes_to_dw = 10,
             control_well_positions = ['G12', 'H12'],
+            pause_between_mastermix_and_elutes: bool = True,
             tube_block_model: str = 'opentrons_24_aluminumblock_nest_2ml_screwcap',
             transfer_elutes_phase: bool = False,
             transfer_proteinase_phase: bool = False,
@@ -42,7 +43,7 @@ class BioerProtocol(Station):
         self._elution_volume = 12
         self._pk_volume = 10
         self._pk_volume_tube = pk_volume_tube
-        self._mm_volume = 20
+        self._mm_volume = 18
         self._mm_volume_tube = mm_volume_tube
         self._mm_tube_bottom_height = mm_tube_bottom_height
         self._dw_bottom_height = dw_bottom_height
@@ -57,6 +58,7 @@ class BioerProtocol(Station):
         self._pk_tube_bottom_height = pk_tube_bottom_height
         self._headroom_vol_from_tubes_to_pcr = headroom_vol_from_tubes_to_pcr
         self._headroom_vol_from_tubes_to_dw = headroom_vol_from_tubes_to_dw
+        self._pause_between_mastermix_and_elutes = pause_between_mastermix_and_elutes
         self._tube_block_model = tube_block_model
         self._mix_beads_phase = mix_beads_phase
         self._mastermix_phase = mastermix_phase
@@ -184,7 +186,8 @@ class BioerProtocol(Station):
             vol_pk = len(samples_to_do) * self._pk_volume
             if num_cycle == 1:
                 self._s300.aspirate(self._vol_pk_offset, self._tube_block.wells()[0].bottom(self._pk_tube_bottom_height))
-            self._pk_tube_source.aspirate_from_tubes(vol_pk, self._s300, self._pk_tube_bottom_height)
+            self._pk_tube_source.calculate_aspirate_volume(vol_pk)
+            self._pk_tube_source.aspirate(self._s300, self._pk_tube_bottom_height)
             #self.logger.info("Aspirating {} at: {} mm".format(vol_pk, self._pk_tube_bottom_height))
             for s, ss in enumerate(samples_to_do):
                 self._s300.dispense(self._pk_volume, ss.bottom(self._dw_bottom_height))
@@ -229,7 +232,8 @@ class BioerProtocol(Station):
             if num_cycle > 1:
                 self._vol_mm_offset = 0
             vol_mm = (len(samples_to_do) * self._mm_volume) + self._vol_mm_offset
-            self._mm_tube_source.aspirate_from_tubes(vol_mm, self._s300, self._mm_tube_bottom_height)
+            self._mm_tube_source.calculate_aspirate_volume(vol_mm)
+            self._mm_tube_source.aspirate(self._s300, self._mm_tube_bottom_height)
             # self.logger.info("Aspirating at: {} mm".format(self._mm_tube_bottom_height))
             for s, ss in enumerate(samples_to_do):
                 self._s300.dispense(self._mm_volume, ss.bottom(self._mm_plate_bottom_height))
@@ -245,6 +249,9 @@ class BioerProtocol(Station):
         source_plate = [row for plate in self._dests_plates for row in plate.columns()[4::6]]
         dests_sample_elute = self._dest_plate_elute.columns()[:self.num_cols]
 
+        if self._pause_between_mastermix_and_elutes:
+            self.dual_pause(self.get_msg_format("insert deepwell", ", ".join([str(d) for d in self._dests_plates])))
+
         self.logger.info("Trasferring elutes from deepwells to pcr plate")
 
         done_col = 0
