@@ -11,6 +11,7 @@ class MultiTubeSource(object):
             self.logger = logger
         else:
             self.logger = logging.getLogger(__name__)
+        self._aspirate_list = []
 
     def append_tube_with_vol(self, source, available_volume):
         self._source_tubes_and_vol.append(dict(source=source,
@@ -18,8 +19,8 @@ class MultiTubeSource(object):
         self.logger.debug("{}: appended {} with {}ul".format(self._name, source, available_volume))
         self.logger.debug("Now sources is: {}".format(self._source_tubes_and_vol))
 
-    def aspirate_from_tubes(self, volume, pip, aspirate_height_from_bottom: float = 2):
-        aspirate_list = []
+    def calculate_aspirate_volume(self, volume) -> list():
+        self._aspirate_list = []
         left_volume = volume
         for source_and_vol in self._source_tubes_and_vol:
             if source_and_vol["available_volume"] >= left_volume:
@@ -30,18 +31,20 @@ class MultiTubeSource(object):
             left_volume -= aspirate_vol
             source_and_vol["available_volume"] -= aspirate_vol
             if aspirate_vol != 0:
-                aspirate_list.append(dict(source=source_and_vol["source"], vol=aspirate_vol))
+                self._aspirate_list.append(dict(source=source_and_vol["source"], vol=aspirate_vol))
 
             if left_volume == 0:
                 break
         else:
             raise Exception("{}: no volume left in source tubes.".format(self._name))
 
-        for a in aspirate_list:
-            pip.aspirate(a["vol"], a["source"].bottom(aspirate_height_from_bottom))
-
         self.logger.debug("{} sources: {}".format(self._name, self._source_tubes_and_vol))
 
+    def aspirate(self, pip, aspirate_height_from_bottom: float = 2):
+        assert self._aspirate_list, "You must call calculate_aspirate_volume before aspirate"
+        for a in self._aspirate_list:
+            pip.aspirate(a["vol"], a["source"].bottom(aspirate_height_from_bottom))
+
     @property
     def locations_str(self):
         return "{}: ".format(self._name) + \
